import { NativeModules, Platform } from 'react-native';
const LINKING_ERROR = `The package 'react-native-pdf-thumbnail' doesn't seem to be linked. Make sure: \n\n` + Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo managed workflow\n';
const PdfThumbnailNativeModule = NativeModules.PdfThumbnail ? NativeModules.PdfThumbnail : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});
const DEFAULT_QUALITY = 80;
const sanitizeQuality = quality => {
  if (quality === undefined) {
    quality = DEFAULT_QUALITY;
  }
  return Math.min(Math.max(quality, 0), 100);
};
export default class PdfThumbnail {
  static async generate(filePath, page, quality) {
    return PdfThumbnailNativeModule.generate(filePath, page, sanitizeQuality(quality));
  }
  static async generateAllPages(filePath, quality) {
    return PdfThumbnailNativeModule.generateAllPages(filePath, sanitizeQuality(quality));
  }
}
//# sourceMappingURL=index.js.map